.. -*- coding: utf-8 -*-

======================
``pybill.lib`` package
======================

.. automodule:: pybill.lib

.. toctree::
   :maxdepth: 2

   lib_errors_index
   lib_controller_index
   lib_entities_index
   lib_config_index
   lib_xmlreaders_index
   lib_xmlwriters_index
   lib_pdfwriters_index
   lib_accounting_index
